from ..Internal.Core import Core
from ..Internal.CommandsGroup import CommandsGroup
from ..Internal.Types import DataType
from ..Internal.ArgSingleList import ArgSingleList
from ..Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Apply:
	"""Apply commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("apply", core, parent)

	def set(self, voltage: float, current: float = None, output: int = None) -> None:
		"""SCPI: APPLy \n
		Snippet: driver.apply.set(voltage = 1.0, current = 1.0, output = 1) \n
		Sets or queries the voltage and current value of the selected channel. \n
			:param voltage: numeric value | MIN | MINimum | MAX | MAXimum | DEF | DEFault numeric value Numeric value for voltage in the range of 0.000 to 20.050. MIN | MINimum Min voltage at 0.000 V. MAX | MAXimum Max value for voltage at 20.050V. DEF | DEFault Default voltage. Unit: V
			:param current: numeric value | MIN | MINimum | MAX | MAXimum | DEFault numeric value Numeric value for current in the range of 0.000 to 6.010. MIN | MINimum Min current at 0.000 A. MAX | MAXimum Max value for current at 6.010 A. DEF | DEFault Numeric value for current. Unit: A
			:param output: OUT1 | OUTP1 | OUTPut1 | OUT2 | OUTP2 | OUTPut2 OUT1 | OUTP1 | OUTPut1 Selects output for channel 1.
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('voltage', voltage, DataType.Float), ArgSingle('current', current, DataType.Float, True), ArgSingle('output', output, DataType.Integer, True))
		self._core.io.write(f'APPLy {param}'.rstrip())



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Communicate:
	"""Communicate commands group definition. 10 total commands, 1 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("communicate", core, parent)

	@property
	def lan(self):
		"""lan commands group. 2 Sub-classes, 8 commands."""
		if not hasattr(self, '_lan'):
			from .Communicate_.Lan import Lan
			self._lan = Lan(self._core, self._base)
		return self._lan



from ..Internal.Core import Core
from ..Internal.CommandsGroup import CommandsGroup
from ..Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Log:
	"""Log commands group definition. 9 total commands, 7 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("log", core, parent)

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Log_.Mode import Mode
			self._mode = Mode(self._core, self._base)
		return self._mode

	@property
	def count(self):
		"""count commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_count'):
			from .Log_.Count import Count
			self._count = Count(self._core, self._base)
		return self._count

	@property
	def duration(self):
		"""duration commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_duration'):
			from .Log_.Duration import Duration
			self._duration = Duration(self._core, self._base)
		return self._duration

	@property
	def interval(self):
		"""interval commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_interval'):
			from .Log_.Interval import Interval
			self._interval = Interval(self._core, self._base)
		return self._interval

	@property
	def fname(self):
		"""fname commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fname'):
			from .Log_.Fname import Fname
			self._fname = Fname(self._core, self._base)
		return self._fname

	@property
	def stime(self):
		"""stime commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_stime'):
			from .Log_.Stime import Stime
			self._stime = Stime(self._core, self._base)
		return self._stime

	@property
	def channel(self):
		"""channel commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_channel'):
			from .Log_.Channel import Channel
			self._channel = Channel(self._core, self._base)
		return self._channel

	def get_state(self) -> bool:
		"""SCPI: LOG[:STATe] \n
		Snippet: value: bool = driver.log.get_state() \n
		Sets or queries the data logging state. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('LOG:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, arg_0: bool) -> None:
		"""SCPI: LOG[:STATe] \n
		Snippet: driver.log.set_state(arg_0 = False) \n
		Sets or queries the data logging state. \n
			:param arg_0: 1 Data logging function is enabled. 0 Data logging function is disabled.
		"""
		param = Conversions.bool_to_str(arg_0)
		self._core.io.write(f'LOG:STATe {param}')

	def get_triggered(self) -> bool:
		"""SCPI: LOG:TRIGgered \n
		Snippet: value: bool = driver.log.get_triggered() \n
		Sets or queries the state for manual trigger logging function. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('LOG:TRIGgered?')
		return Conversions.str_to_bool(response)

	def set_triggered(self, arg_0: bool) -> None:
		"""SCPI: LOG:TRIGgered \n
		Snippet: driver.log.set_triggered(arg_0 = False) \n
		Sets or queries the state for manual trigger logging function. \n
			:param arg_0: 0 Manual trigger function is disabled. 1 Manual trigger function is enabled.
		"""
		param = Conversions.bool_to_str(arg_0)
		self._core.io.write(f'LOG:TRIGgered {param}')



from enum import Enum
from .Internal.RepeatedCapability import VALUE_DEFAULT
from .Internal.RepeatedCapability import VALUE_EMPTY


# noinspection SpellCheckingInspection
class Channel(Enum):
	"""Repeated capability Channel \n
	Channel"""
	Empty = VALUE_EMPTY
	Default = VALUE_DEFAULT
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3
	Nr4 = 4



from ..Internal.Core import Core
from ..Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Trigger:
	"""Trigger commands group definition. 7 total commands, 2 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("trigger", core, parent)

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .Trigger_.State import State
			self._state = State(self._core, self._base)
		return self._state

	@property
	def sequence(self):
		"""sequence commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_sequence'):
			from .Trigger_.Sequence import Sequence
			self._sequence = Sequence(self._core, self._base)
		return self._sequence



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Local:
	"""Local commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("local", core, parent)

	def set(self) -> None:
		"""SCPI: SYSTem:LOCal \n
		Snippet: driver.system.local.set() \n
		Sets the system to front panel control. The front panel control is unlocked. If the front panel control was locked with
		the SCPI command method RsNgx.System.RwLock.set, the message box of the locked front panel on the instrument display will
		be disappeared. \n
		"""
		self._core.io.write(f'SYSTem:LOCal')

	def set_with_opc(self) -> None:
		"""SCPI: SYSTem:LOCal \n
		Snippet: driver.system.local.set_with_opc() \n
		Sets the system to front panel control. The front panel control is unlocked. If the front panel control was locked with
		the SCPI command method RsNgx.System.RwLock.set, the message box of the locked front panel on the instrument display will
		be disappeared. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsNgx.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'SYSTem:LOCal')



from ..Internal.Core import Core
from ..Internal.CommandsGroup import CommandsGroup
from ..Internal.Utilities import trim_str_response
from ..Internal.StructBase import StructBase
from ..Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class System:
	"""System commands group definition. 28 total commands, 9 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("system", core, parent)

	@property
	def beeper(self):
		"""beeper commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_beeper'):
			from .System_.Beeper import Beeper
			self._beeper = Beeper(self._core, self._base)
		return self._beeper

	@property
	def key(self):
		"""key commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_key'):
			from .System_.Key import Key
			self._key = Key(self._core, self._base)
		return self._key

	@property
	def local(self):
		"""local commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_local'):
			from .System_.Local import Local
			self._local = Local(self._core, self._base)
		return self._local

	@property
	def remote(self):
		"""remote commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_remote'):
			from .System_.Remote import Remote
			self._remote = Remote(self._core, self._base)
		return self._remote

	@property
	def rwLock(self):
		"""rwLock commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rwLock'):
			from .System_.RwLock import RwLock
			self._rwLock = RwLock(self._core, self._base)
		return self._rwLock

	@property
	def restart(self):
		"""restart commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_restart'):
			from .System_.Restart import Restart
			self._restart = Restart(self._core, self._base)
		return self._restart

	@property
	def setting(self):
		"""setting commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_setting'):
			from .System_.Setting import Setting
			self._setting = Setting(self._core, self._base)
		return self._setting

	@property
	def communicate(self):
		"""communicate commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_communicate'):
			from .System_.Communicate import Communicate
			self._communicate = Communicate(self._core, self._base)
		return self._communicate

	@property
	def vnc(self):
		"""vnc commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_vnc'):
			from .System_.Vnc import Vnc
			self._vnc = Vnc(self._core, self._base)
		return self._vnc

	# noinspection PyTypeChecker
	class DateStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Arg_0: float: No parameter help available
			- Arg_1: float: No parameter help available
			- Arg_2: float: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_float('Arg_0'),
			ArgStruct.scalar_float('Arg_1'),
			ArgStruct.scalar_float('Arg_2')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Arg_0: float = None
			self.Arg_1: float = None
			self.Arg_2: float = None

	def get_date(self) -> DateStruct:
		"""SCPI: SYSTem:DATE \n
		Snippet: value: DateStruct = driver.system.get_date() \n
		Sets or queries the system date. \n
			:return: structure: for return value, see the help for DateStruct structure arguments.
		"""
		return self._core.io.query_struct('SYSTem:DATE?', self.__class__.DateStruct())

	def set_date(self, value: DateStruct) -> None:
		"""SCPI: SYSTem:DATE \n
		Snippet: driver.system.set_date(value = DateStruct()) \n
		Sets or queries the system date. \n
			:param value: see the help for DateStruct structure arguments.
		"""
		self._core.io.write_struct('SYSTem:DATE', value)

	# noinspection PyTypeChecker
	class TimeStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Arg_0: int: No parameter help available
			- Arg_1: int: No parameter help available
			- Arg_2: int: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_int('Arg_0'),
			ArgStruct.scalar_int('Arg_1'),
			ArgStruct.scalar_int('Arg_2')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Arg_0: int = None
			self.Arg_1: int = None
			self.Arg_2: int = None

	def get_time(self) -> TimeStruct:
		"""SCPI: SYSTem:TIME \n
		Snippet: value: TimeStruct = driver.system.get_time() \n
		Sets or queries the system time. \n
			:return: structure: for return value, see the help for TimeStruct structure arguments.
		"""
		return self._core.io.query_struct('SYSTem:TIME?', self.__class__.TimeStruct())

	def set_time(self, value: TimeStruct) -> None:
		"""SCPI: SYSTem:TIME \n
		Snippet: driver.system.set_time(value = TimeStruct()) \n
		Sets or queries the system time. \n
			:param value: see the help for TimeStruct structure arguments.
		"""
		self._core.io.write_struct('SYSTem:TIME', value)

	def get_up_time(self) -> str:
		"""SCPI: SYSTem:UPTime \n
		Snippet: value: str = driver.system.get_up_time() \n
		No command help available \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('SYSTem:UPTime?')
		return trim_str_response(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Output:
	"""Output commands group definition. 1 total commands, 1 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("output", core, parent)

	@property
	def channel(self):
		"""channel commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_channel'):
			from .Output_.Channel import Channel
			self._channel = Channel(self._core, self._base)
		return self._channel



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Condition:
	"""Condition commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("condition", core, parent)

	def get(self, channel=repcap.Channel.Default) -> int:
		"""SCPI: STATus:OPERation:INSTrument:ISUMmary<Channel>:CONDition \n
		Snippet: value: int = driver.status.operation.instrument.isummary.condition.get(channel = repcap.Channel.Default) \n
		Returns the contents of the CONDition part of the status register to check for operation instrument or measurement states.
		Reading the CONDition registers does not delete the contents. \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Isummary')
			:return: result: No help available"""
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'STATus:OPERation:INSTrument:ISUMmary{channel_cmd_val}:CONDition?')
		return Conversions.str_to_int(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class WarningPy:
	"""WarningPy commands group definition. 2 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("warningPy", core, parent)

	@property
	def immediate(self):
		"""immediate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_immediate'):
			from .WarningPy_.Immediate import Immediate
			self._immediate = Immediate(self._core, self._base)
		return self._immediate

	def get_state(self) -> bool:
		"""SCPI: SYSTem:BEEPer:WARNing:STATe \n
		Snippet: value: bool = driver.system.beeper.warningPy.get_state() \n
		No command help available \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('SYSTem:BEEPer:WARNing:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, arg_0: bool) -> None:
		"""SCPI: SYSTem:BEEPer:WARNing:STATe \n
		Snippet: driver.system.beeper.warningPy.set_state(arg_0 = False) \n
		No command help available \n
			:param arg_0: No help available
		"""
		param = Conversions.bool_to_str(arg_0)
		self._core.io.write(f'SYSTem:BEEPer:WARNing:STATe {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Remote:
	"""Remote commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("remote", core, parent)

	def set(self) -> None:
		"""SCPI: SYSTem:REMote \n
		Snippet: driver.system.remote.set() \n
		Sets the system to remote state. The front panel control is locked. By pushing the softkey button [*] key, the front
		panel control will be activated. \n
		"""
		self._core.io.write(f'SYSTem:REMote')

	def set_with_opc(self) -> None:
		"""SCPI: SYSTem:REMote \n
		Snippet: driver.system.remote.set_with_opc() \n
		Sets the system to remote state. The front panel control is locked. By pushing the softkey button [*] key, the front
		panel control will be activated. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsNgx.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'SYSTem:REMote')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Setting:
	"""Setting commands group definition. 1 total commands, 1 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("setting", core, parent)

	@property
	def default(self):
		"""default commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_default'):
			from .Setting_.Default import Default
			self._default = Default(self._core, self._base)
		return self._default



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Current:
	"""Current commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("current", core, parent)

	def get_state(self) -> bool:
		"""SCPI: SYSTem:BEEPer:CURRent:STATe \n
		Snippet: value: bool = driver.system.beeper.current.get_state() \n
		Enables or disables beep sound for 'current control' alert. \n
			:return: arg_0: 1 Enables the 'Current control' beep sound, a continuous beep sound alert when the selected output channel goes into CC mode. 0 Disables the 'Current control' beep sound.
		"""
		response = self._core.io.query_str('SYSTem:BEEPer:CURRent:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, arg_0: bool) -> None:
		"""SCPI: SYSTem:BEEPer:CURRent:STATe \n
		Snippet: driver.system.beeper.current.set_state(arg_0 = False) \n
		Enables or disables beep sound for 'current control' alert. \n
			:param arg_0: 1 Enables the 'Current control' beep sound, a continuous beep sound alert when the selected output channel goes into CC mode. 0 Disables the 'Current control' beep sound.
		"""
		param = Conversions.bool_to_str(arg_0)
		self._core.io.write(f'SYSTem:BEEPer:CURRent:STATe {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Triggered:
	"""Triggered commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("triggered", core, parent)

	def get_state(self) -> bool:
		"""SCPI: ARBitrary:TRIGgered[:STATe] \n
		Snippet: value: bool = driver.arbitrary.triggered.get_state() \n
		Sets or queries the arbitrary trigger mode. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('ARBitrary:TRIGgered:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, arg_0: bool) -> None:
		"""SCPI: ARBitrary:TRIGgered[:STATe] \n
		Snippet: driver.arbitrary.triggered.set_state(arg_0 = False) \n
		Sets or queries the arbitrary trigger mode. \n
			:param arg_0: 0 OFF - Trigger input is deactivated. 1 ON - Trigger input is activated.
		"""
		param = Conversions.bool_to_str(arg_0)
		self._core.io.write(f'ARBitrary:TRIGgered:STATe {param}')

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.ArbTrigMode:
		"""SCPI: ARBitrary:TRIGgered:MODE \n
		Snippet: value: enums.ArbTrigMode = driver.arbitrary.triggered.get_mode() \n
		Sets or queries the arbitrary trigger mode of the previous selected channel. \n
			:return: arg_0: No help available
		"""
		response = self._core.io.query_str('ARBitrary:TRIGgered:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.ArbTrigMode)

	def set_mode(self, arg_0: enums.ArbTrigMode) -> None:
		"""SCPI: ARBitrary:TRIGgered:MODE \n
		Snippet: driver.arbitrary.triggered.set_mode(arg_0 = enums.ArbTrigMode.RUN) \n
		Sets or queries the arbitrary trigger mode of the previous selected channel. \n
			:param arg_0: SINGle | RUN SINGle A trigger event starts only with one arbitrary sequence. RUN A trigger event starts the whole arbitrary sequences (with all repetitions) .
		"""
		param = Conversions.enum_scalar_to_str(arg_0, enums.ArbTrigMode)
		self._core.io.write(f'ARBitrary:TRIGgered:MODE {param}')



from ..Internal.Core import Core
from ..Internal.CommandsGroup import CommandsGroup
from ..Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Display:
	"""Display commands group definition. 3 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("display", core, parent)

	@property
	def window(self):
		"""window commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_window'):
			from .Display_.Window import Window
			self._window = Window(self._core, self._base)
		return self._window

	def get_brightness(self) -> float:
		"""SCPI: DISPlay:BRIGhtness \n
		Snippet: value: float = driver.display.get_brightness() \n
		Sets or queries the display brightness. \n
			:return: new_value_for_display_brightness: No help available
		"""
		response = self._core.io.query_str('DISPlay:BRIGhtness?')
		return Conversions.str_to_float(response)

	def set_brightness(self, new_value_for_display_brightness: float) -> None:
		"""SCPI: DISPlay:BRIGhtness \n
		Snippet: driver.display.set_brightness(new_value_for_display_brightness = 1.0) \n
		Sets or queries the display brightness. \n
			:param new_value_for_display_brightness: Displays brightness for the instrument. Range: 0.0 to 1.0
		"""
		param = Conversions.decimal_value_to_str(new_value_for_display_brightness)
		self._core.io.write(f'DISPlay:BRIGhtness {param}')



from ..Internal.Core import Core
from ..Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Instrument:
	"""Instrument commands group definition. 1 total commands, 1 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("instrument", core, parent)

	@property
	def select(self):
		"""select commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_select'):
			from .Instrument_.Select import Select
			self._select = Select(self._core, self._base)
		return self._select
